
The ``sig-networks`` Python package
======================================

``sig-networks``
-------------------

The ``sig-networks`` library provides functionality for training and evaluating neural networks for longitudinal NLP classification tasks.

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: API
   :glob:

   baseline_models.rst
   swnu.rst
   sw_attention.rst
   seqsignet_models.rst

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: About
   :glob:

   authors.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
